4.9. stacking — EQcorrscan 0.1.0 documentation

# 4.9. stacking

Utility module of the EQcorrscan package to allow for different methods of stacking of seismic signal in one place.

Calum Chamberlain 24/06/2015

Copyright 2015 Calum Chamberlain

This file is part of EQcorrscan.

> EQcorrscan is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

> EQcorrscan is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

> You should have received a copy of the GNU General Public License along with EQcorrscan. If not, see <http://www.gnu.org/licenses/>.

`stacking.` `PWS_stack`(streams, weight=2)

  Function to compute the phase weighted stack of a series of streams. Recommend aligning the traces before stacking.

  Parameters: | streams (list of obspy.Stream) – List of Stream to stack weight (float) – Exponent to the phase stack used for weighting.
  Returns: | obspy.Stream

`stacking.` `align_traces`(trace_list, shift_len, master=False)

  Function to allign traces relative to each other based on their cross-correlation value.

  Parameters: | trace_list (list of Traces) – List of traces to allign shift_len (int) – Length to allow shifting within in samples master (obspy.Trace) – Master trace to align to, if set to False will align to the largest amplitude trace (default)
  Returns: | list of shifts for best allignment in seconds

`stacking.` `linstack`(streams)

  Function to compute the linear stack of a series of seismic streams of multiplexed data.

  Parameters: | stream – List of streams to stack
  Returns: | stack - Stream